@@ -1,9 +1,10 @@
 import zarr
 import h5py
 
+from pathlib import Path
 
-EPITHELIAL_ZARR = "sample_data/per01_100.zarr"
-LIGHTSHEET_H5 = "sample_data/lightsheet_nuclei_test_data"
+EPITHELIAL_ZARR = Path(__file__).parent / "sample_data/per01_100.zarr"
+LIGHTSHEET_H5 = Path(__file__).parent / "sample_data/lightsheet_nuclei_test_data"
 
 
 def sample_epithelial():
@@ -25,22 +26,6 @@ def sample_epithelial():
             },
             "labels",
         ),
-        (
-            container["volumes/gt_tanh"][:],
-            {
-                "name": "TanH",
-                "metadata": {"axes": ["y", "x"]},
-            },
-            "image",
-        ),
-        (
-            container["volumes/gt_fgbg"][:],
-            {
-                "name": "FG/BG",
-                "metadata": {"axes": ["y", "x"]},
-            },
-            "labels",
-        ),
     ]
 
 
@@ -48,7 +33,7 @@ def sample_lightsheet():
     container = h5py.File(LIGHTSHEET_H5)
     return [
         (
-            container["raw"][100:260, 200:360, 400:560] / 255,
+            container["raw"][:] / 255,
             {
                 "name": "Raw",
                 "metadata": {"axes": ["z", "y", "x"]},
